'use strict';

Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });

const validationHtml = require('@aurelia/validation-html');
const tslib = require('tslib');
const runtimeHtml = require('@aurelia/runtime-html');
const kernel = require('@aurelia/kernel');
const topAppBar = require('@material/top-app-bar');
const drawer = require('@material/drawer');
require('devextreme/dist/css/dx.material.purple.dark.compact.css');
const dialog = require('@material/dialog');
const textfield = require('@material/textfield');
const runtime = require('@aurelia/runtime');
const circularProgress = require('@material/circular-progress');
const ripple = require('@material/ripple');
require('@material/web/switch/switch');
const tabBar = require('@material/tab-bar');
const banner = require('@material/banner');
const radio = require('@material/radio');
const formField = require('@material/form-field');
const chips = require('@material/chips');
const checkbox = require('@material/checkbox');
const menu = require('@material/menu');

let Align = class Align {
    element;
    value;
    constructor(element){
        this.element = element;
    }
    afterBind() {
        this.element.style.textAlign = this.value ?? '';
    }
    /* Example of change detection */ valueChanged() {
        this.afterBind();
    }
};
tslib.__decorate([
    runtimeHtml.bindable(),
    tslib.__metadata("design:type", String)
], Align.prototype, "value", void 0);
Align = tslib.__decorate([
    runtimeHtml.customAttribute({
        name: 'align'
    }),
    tslib.__param(0, runtimeHtml.INode),
    tslib.__metadata("design:paramtypes", [
        HTMLElement
    ])
], Align);

let FullHeight = class FullHeight {
    element;
    constructor(element){
        this.element = element;
        this.element.style.height = '100%';
    }
};
FullHeight = tslib.__decorate([
    runtimeHtml.customAttribute({
        name: 'full-height'
    }),
    tslib.__param(0, runtimeHtml.INode),
    tslib.__metadata("design:paramtypes", [
        HTMLElement
    ])
], FullHeight);

let FullWidth = class FullWidth {
    element;
    constructor(element){
        this.element = element;
        this.element.style.width = '100%';
    }
};
FullWidth = tslib.__decorate([
    runtimeHtml.customAttribute({
        name: 'full-width'
    }),
    tslib.__param(0, runtimeHtml.INode),
    tslib.__metadata("design:paramtypes", [
        HTMLElement
    ])
], FullWidth);

let Link = class Link {
    htmlElement;
    platform;
    value = '';
    constructor(htmlElement, platform){
        this.htmlElement = htmlElement;
        this.platform = platform;
        htmlElement.addEventListener('mousedown', this.clickEvent);
    }
    clickEvent = ()=>{
        // eslint-disable-next-line @typescript-eslint/ban-ts-comment
        //@ts-ignore
        this.platform.window.open(this.value, '_blank');
    };
    detaching() {
        this.htmlElement.removeEventListener('mousedown', this.clickEvent);
    }
};
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Object)
], Link.prototype, "value", void 0);
Link = tslib.__decorate([
    runtimeHtml.customAttribute({
        name: 'link',
        noMultiBindings: true
    }),
    tslib.__param(0, runtimeHtml.INode),
    tslib.__param(1, kernel.IPlatform),
    tslib.__metadata("design:paramtypes", [
        HTMLElement,
        Object
    ])
], Link);

let Ripple = class Ripple {
    htmlElement;
    platform;
    speed = 1;
    color = '';
    rippleContainer;
    ripple;
    constructor(htmlElement, platform){
        this.htmlElement = htmlElement;
        this.platform = platform;
        htmlElement?.addEventListener('mousedown', this.rippleEvent);
    }
    rippleEvent = (event)=>{
        if (!this.htmlElement) return;
        const offsetInfo = this.htmlElement.getBoundingClientRect();
        this.createContainer(offsetInfo);
        this.createRipple(offsetInfo, event);
    };
    createRipple = (offsetInfo, event)=>{
        const maxLength = offsetInfo.width > offsetInfo.height ? offsetInfo.width : offsetInfo.height;
        const circleD = maxLength * 2;
        this.ripple = document.createElement('div');
        this.ripple.style.position = 'absolute';
        this.ripple.style.pointerEvents = 'none';
        this.ripple.style.width = `${circleD}px`;
        this.ripple.style.height = `${circleD}px`;
        this.ripple.style.borderRadius = '500px';
        this.ripple.style.left = `${event.pageX - offsetInfo.left - circleD / 2}px`;
        this.ripple.style.top = `${event.pageY - offsetInfo.top - circleD / 2}px`;
        this.ripple.style.animationDuration = `${this.speed}s`;
        this.ripple.style.background = this.color || 'rgba(var(--san-juan-900-rgb), var(--alpha-sm))';
        this.ripple.className = 'ripple';
        this.rippleContainer?.appendChild(this.ripple);
        this.ripple.addEventListener('animationend', this.removeContainer, false);
    };
    createContainer(offsetInfo) {
        if (!this.htmlElement) return;
        const ripplerContainer = this.htmlElement.querySelector('.ripple-container');
        if (ripplerContainer) {
            ripplerContainer.remove();
        }
        this.rippleContainer = document.createElement('div');
        this.rippleContainer.style.position = 'fixed';
        this.rippleContainer.style.zIndex = '99';
        this.rippleContainer.style.width = `${offsetInfo.width}px`;
        this.rippleContainer.style.left = `${offsetInfo.left}px`;
        this.rippleContainer.style.top = `${offsetInfo.top}px`;
        this.rippleContainer.style.height = `${offsetInfo.height}px`;
        this.rippleContainer.className = 'ripple-container';
        this.rippleContainer.style.pointerEvents = 'none';
        this.rippleContainer.style.overflow = 'hidden';
        this.htmlElement.appendChild(this.rippleContainer);
    }
    removeContainer = ()=>{
        this.rippleContainer?.remove();
        this.ripple?.removeEventListener('animationend', this.removeContainer);
    };
    detaching() {
        if (!this.htmlElement) return;
        this.htmlElement.removeEventListener('mousedown', this.rippleEvent);
    }
};
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Object)
], Ripple.prototype, "speed", void 0);
tslib.__decorate([
    runtimeHtml.bindable({
        primary: true
    }),
    tslib.__metadata("design:type", Object)
], Ripple.prototype, "color", void 0);
Ripple = tslib.__decorate([
    runtimeHtml.customAttribute({
        name: 'ripple'
    }),
    tslib.__param(1, kernel.IPlatform),
    tslib.__metadata("design:paramtypes", [
        HTMLElement,
        Object
    ])
], Ripple);

let Underline = class Underline {
    element;
    constructor(element){
        this.element = element;
        this.element.style.textDecoration = 'underline';
    }
};
Underline = tslib.__decorate([
    runtimeHtml.customAttribute({
        name: 'underline'
    }),
    tslib.__param(0, runtimeHtml.INode),
    tslib.__metadata("design:paramtypes", [
        HTMLElement
    ])
], Underline);

let Elevation = class Elevation {
    element;
    value;
    constructor(element){
        this.element = element;
        this.element.style.boxShadow = '0 8px 12px rgba(0, 0, 0, 0.1), 0 2px 6px rgba(0, 0, 0, 0.08)';
        //this.element.style.border = "1px solid black";
        this.element.style.borderRadius = '5px';
    }
};
tslib.__decorate([
    runtimeHtml.bindable(),
    tslib.__metadata("design:type", String)
], Elevation.prototype, "value", void 0);
Elevation = tslib.__decorate([
    runtimeHtml.customAttribute({
        name: 'elevation'
    }),
    tslib.__param(0, runtimeHtml.INode),
    tslib.__metadata("design:paramtypes", [
        HTMLElement
    ])
], Elevation);

const attributes = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
    __proto__: null,
    get Align () { return Align; },
    get Elevation () { return Elevation; },
    get FullHeight () { return FullHeight; },
    get FullWidth () { return FullWidth; },
    get Link () { return Link; },
    get Ripple () { return Ripple; },
    get Underline () { return Underline; }
}, Symbol.toStringTag, { value: 'Module' }));

const IBetsyWebComponentsConfiguration = kernel.DI.createInterface('IBetsyWebComponentsConfiguration');

const mooButton = '';

const template$o = "<button class=\"moo-button ${colorClass} ${class}\" ref=\"button\" type=\"${type}\" if.bind=\"!hasClickFunction\" data-mdc-dialog-action.bind=\"dataMdcDialogAction\" disabled.bind=\"disabled\">\n    <span class=\"material-icons\" if.bind=\"icon\">${icon}</span>\n    ${label}<au-slot></au-slot>\n</button>\n\n<button else class=\"moo-button ${colorClass} ${class}\" ref=\"button\" type=\"${type}\" click.trigger=\"handleClick()\" data-mdc-dialog-action.bind=\"dataMdcDialogAction\" disabled.bind=\"disabled\">\n    <span class=\"material-icons\" if.bind=\"icon\">${icon}</span>\n    ${label}<au-slot></au-slot>\n</button>\n";

let MooButton = class MooButton {
    button;
    label;
    type;
    icon;
    variant = 'primary';
    class = '';
    click;
    dataMdcDialogAction;
    disabled = false;
    get colorClass() {
        switch(this.variant){
            case 'primary':
                return '';
            case 'secondary':
                return 'moo-button-secondary';
        }
    }
    handleClick() {
        if (this.click) {
            this.click();
        }
    }
    get hasClickFunction() {
        return typeof this.click === 'function';
    }
};
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", String)
], MooButton.prototype, "label", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", String)
], MooButton.prototype, "type", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", String)
], MooButton.prototype, "icon", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", String)
], MooButton.prototype, "variant", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Object)
], MooButton.prototype, "class", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Function)
], MooButton.prototype, "click", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Object)
], MooButton.prototype, "dataMdcDialogAction", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Object)
], MooButton.prototype, "disabled", void 0);
MooButton = tslib.__decorate([
    runtimeHtml.customElement({
        name: 'moo-button',
        template: template$o,
        containerless: true
    })
], MooButton);

const mooTopbar = '';

const template$n = "<header class=\"mdc-top-app-bar mdc-top-app-bar--fixed\" ref=\"header\">\n    <div class=\"mdc-top-app-bar__row\">\n        <au-slot></au-slot>\n    </div>\n</header>\n<div class=\"mdc-top-app-bar--fixed-adjust\"></div>\n";

let MooTopbar = class MooTopbar {
    header;
    attached() {
        new topAppBar.MDCTopAppBar(this.header);
    }
};
MooTopbar = tslib.__decorate([
    runtimeHtml.customElement({
        name: 'moo-topbar',
        template: template$n,
        containerless: true
    })
], MooTopbar);

const mooDrawer = '';

const template$m = "<div if.bind=\"!open\">\n    <moo-fab icon=\"chevron_right\" click.bind=\"() => open = true\" class=\"bottomRight\"></moo-fab>\n</div>\n<aside class=\"mdc-drawer mdc-drawer--dismissible\" ref=\"drawerEl\">\n    <div class=\"close-icon\">\n        <moo-fab icon=\"chevron_left\" click.bind=\"() => open = false\" class=\"topRight\"></moo-fab>\n    </div>\n    <div class=\"mdc-drawer__content\">\n        <au-slot></au-slot>\n    </div>\n</aside>\n";

let MooDrawer = class MooDrawer {
    open;
    drawerEl;
    drawer;
    didAttach = false;
    attached() {
        if (!this.didAttach) {
            this.drawer = drawer.MDCDrawer.attachTo(this.drawerEl);
            this.drawer.open = this.open;
            this.didAttach = true;
        }
    }
    openChanged() {
        this.drawer.open = this.open;
    }
};
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Boolean)
], MooDrawer.prototype, "open", void 0);
MooDrawer = tslib.__decorate([
    runtimeHtml.customElement({
        name: 'moo-drawer',
        template: template$m,
        containerless: true
    })
], MooDrawer);

const mooDialog = '';

const template$l = "<div class=\"mdc-dialog\" ref=\"dialogEl\">\n    <div class=\"mdc-dialog__container\">\n        <div class=\"mdc-dialog__surface\"\n             role=\"alertdialog\"\n             aria-modal=\"true\"\n             aria-labelledby=\"my-dialog-title\"\n             aria-describedby=\"my-dialog-content\">\n            <h2 class=\"mdc-dialog__title\" id=\"my-dialog-title\" if.bind=\"title\">${title}</h2>\n            <div class=\"mdc-dialog__content\" id=\"my-dialog-content\">\n                <au-slot></au-slot>\n            </div>\n            <div class=\"mdc-dialog__actions\">\n                <moo-button type=\"button\" variant=\"secondary\" data-mdc-dialog-action=\"cancel\">\n                    Cancel\n                </moo-button>\n                <moo-button type=\"button\" variant=\"primary\" data-mdc-dialog-action=\"ok\" class=\"ms-3\">\n                    Confirm\n                </moo-button>\n            </div>\n        </div>\n    </div>\n    <div class=\"mdc-dialog__scrim\"></div>\n</div>\n";

let MooDialog = class MooDialog {
    dialogEl;
    dialog;
    handler;
    title;
    attached() {
        this.dialog = new dialog.MDCDialog(this.dialogEl);
        this.dialog.listen('MDCDialog:closed', (e)=>{
            if (this.handler) {
                this.handler(e);
            }
        });
    }
};
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", HTMLElement)
], MooDialog.prototype, "dialogEl", void 0);
tslib.__decorate([
    runtimeHtml.bindable({
        mode: 6 /* BindingMode.twoWay */ 
    }),
    tslib.__metadata("design:type", dialog.MDCDialog)
], MooDialog.prototype, "dialog", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Function)
], MooDialog.prototype, "handler", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", String)
], MooDialog.prototype, "title", void 0);
MooDialog = tslib.__decorate([
    runtimeHtml.customElement({
        name: 'moo-dialog',
        template: template$l,
        containerless: true
    })
], MooDialog);

const mooCard = '';

const template$k = "<div class=\"card\">\n    <au-slot></au-slot>\n</div>\n";

let MooCard = class MooCard {
    outlined;
};
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Boolean)
], MooCard.prototype, "outlined", void 0);
MooCard = tslib.__decorate([
    runtimeHtml.customElement({
        name: 'moo-banner',
        template: template$k,
        containerless: true
    })
], MooCard);

const template$j = "<div class=\"card-header\">\n    <au-slot></au-slot>\n</div>\n";

let MooCardHeader = class MooCardHeader {
    outlined;
};
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Boolean)
], MooCardHeader.prototype, "outlined", void 0);
MooCardHeader = tslib.__decorate([
    runtimeHtml.customElement({
        name: 'moo-card-header',
        template: template$j,
        containerless: true
    })
], MooCardHeader);

const template$i = "<div class=\"card-content\">\n    <au-slot></au-slot>\n</div>\n";

let MooCardContent = class MooCardContent {
    outlined;
};
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Boolean)
], MooCardContent.prototype, "outlined", void 0);
MooCardContent = tslib.__decorate([
    runtimeHtml.customElement({
        name: 'moo-card-content',
        template: template$i,
        containerless: true
    })
], MooCardContent);

const template$h = "<div class=\"card-footer\">\n    <au-slot></au-slot>\n</div>\n";

let MooCardFooter = class MooCardFooter {
    outlined;
};
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Boolean)
], MooCardFooter.prototype, "outlined", void 0);
MooCardFooter = tslib.__decorate([
    runtimeHtml.customElement({
        name: 'moo-card-footer',
        template: template$h,
        containerless: true
    })
], MooCardFooter);

const template$g = "<a load=\"${route}\" if.bind=\"route\">\n    <li class=\"mdc-deprecated-list-item ${disabledClass}\" data-value=\"${value}\">\n        <span class=\"mdc-deprecated-list-item__ripple\"></span>\n        <span class=\"mdc-deprecated-list-item__text\">${label}</span>\n    </li>\n</a>\n<li class=\"mdc-deprecated-list-item ${disabledClass}\" data-value=\"${value}\" click.trigger=\"clickHandler()\" else>\n    <span class=\"mdc-deprecated-list-item__ripple\"></span>\n    <span class=\"mdc-deprecated-list-item__text\">${label}</span>\n</li>\n";

let MooListItem = class MooListItem {
    label;
    value;
    route;
    click;
    disabled = false;
    clickHandler() {
        if (this.click) {
            this.click(this.value);
        }
    }
    get disabledClass() {
        if (this.disabled) {
            return 'mdc-deprecated-list-item--disabled';
        }
    }
};
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", String)
], MooListItem.prototype, "label", void 0);
tslib.__decorate([
    runtimeHtml.bindable({
        mode: 6 /* BindingMode.twoWay */ 
    }),
    tslib.__metadata("design:type", Object)
], MooListItem.prototype, "value", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", String)
], MooListItem.prototype, "route", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Function)
], MooListItem.prototype, "click", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Object)
], MooListItem.prototype, "disabled", void 0);
MooListItem = tslib.__decorate([
    runtimeHtml.customElement({
        name: 'moo-list-item',
        template: template$g,
        containerless: true
    })
], MooListItem);

const mooTextField = '';

const template$f = "<div switch.bind=\"type\">\n    <label class=\"mdc-text-field mdc-text-field--filled ${class} ${floatLabelClass}\" case.bind=\"['text', 'number']\" ref=\"input\">\n        <span class=\"mdc-text-field__ripple\"></span>\n        <span class=\"mdc-floating-label\" id=\"my-label-id\">${label}</span>\n        <input class=\"mdc-text-field__input\"\n               type.bind=\"type\"\n               aria-labelledby=\"my-label-id\"\n               value.bind=\"value\"\n               required.bind=\"required\"\n               readonly.bind=\"readonly\"\n               minlength.bind=\"minlength\"\n               maxlength.bind=\"maxlength\"\n               min.bind=\"min\"\n               max.bind=\"max\"\n               placeholder.bind=\"placeholder\"\n        >\n    </label>\n    <label class=\"mdc-text-field mdc-text-field--outlined mdc-text-field--textarea mdc-text-field--no-label ${class}\"\n           case=\"textarea\" ref=\"input\">\n            <span class=\"mdc-notched-outline\">\n              <span class=\"mdc-notched-outline__leading\"></span>\n              <span class=\"mdc-notched-outline__trailing\"></span>\n            </span>\n        <span class=\"mdc-text-field__resizer\">\n              <textarea\n                  class=\"mdc-text-field__input\"\n                  rows.bind=\"rows\"\n                  cols.bind=\"cols\"\n                  aria-label=\"${label}\"\n                  value.bind=\"value\"\n                  readonly.bind=\"readonly\"\n                  minlength.bind=\"min\"\n                  maxlength=\"max\"\n                  placeholder.bind=\"placeholder\"\n              ></textarea>\n            </span>\n    </label>\n    <div class=\"mdc-text-field-helper-line\" if.bind=\"maxlength\">\n        <div class=\"mdc-text-field-character-counter\">${value.length} / ${maxlength}</div>\n    </div>\n</div>\n";

let MooTextField = class MooTextField {
    value;
    label;
    class;
    type = 'text';
    rows;
    cols;
    input;
    readonly;
    min;
    max;
    minlength;
    maxlength;
    required;
    placeholder;
    textField;
    attached() {
        if (this.input) {
            this.textField = new textfield.MDCTextField(this.input);
        }
    }
    get floatLabelClass() {
        if (this.value == undefined) {
            return '';
        }
        return 'mdc-text-field--label-floating';
    }
};
tslib.__decorate([
    runtimeHtml.bindable({
        mode: 6 /* BindingMode.twoWay */ 
    }),
    tslib.__metadata("design:type", Object)
], MooTextField.prototype, "value", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Object)
], MooTextField.prototype, "label", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Object)
], MooTextField.prototype, "class", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Object)
], MooTextField.prototype, "type", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Object)
], MooTextField.prototype, "rows", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Object)
], MooTextField.prototype, "cols", void 0);
tslib.__decorate([
    runtime.observable,
    tslib.__metadata("design:type", HTMLElement)
], MooTextField.prototype, "input", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Object)
], MooTextField.prototype, "readonly", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Number)
], MooTextField.prototype, "min", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Number)
], MooTextField.prototype, "max", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Number)
], MooTextField.prototype, "minlength", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Number)
], MooTextField.prototype, "maxlength", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Object)
], MooTextField.prototype, "required", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Object)
], MooTextField.prototype, "placeholder", void 0);
MooTextField = tslib.__decorate([
    runtimeHtml.customElement({
        name: 'moo-text-field',
        template: template$f,
        containerless: true
    })
], MooTextField);

const mooCircularProgress = '';

const template$e = "<div class=\"mdc-circular-progress\" style=\"width:48px;height:48px;\" role=\"progressbar\" aria-label=\"Example Progress Bar\" aria-valuemin=\"0\" aria-valuemax=\"1\" ref=\"progressEl\">\n    <div class=\"mdc-circular-progress__determinate-container\">\n        <svg class=\"mdc-circular-progress__determinate-circle-graphic\" viewBox=\"0 0 48 48\" xmlns=\"http://www.w3.org/2000/svg\">\n            <circle class=\"mdc-circular-progress__determinate-track\" cx=\"24\" cy=\"24\" r=\"18\" stroke-width=\"4\"/>\n            <circle class=\"mdc-circular-progress__determinate-circle\" cx=\"24\" cy=\"24\" r=\"18\" stroke-dasharray=\"113.097\" stroke-dashoffset=\"113.097\" stroke-width=\"4\"/>\n        </svg>\n    </div>\n    <div class=\"mdc-circular-progress__indeterminate-container\">\n        <div class=\"mdc-circular-progress__spinner-layer\">\n            <div class=\"mdc-circular-progress__circle-clipper mdc-circular-progress__circle-left\">\n                <svg class=\"mdc-circular-progress__indeterminate-circle-graphic\" viewBox=\"0 0 48 48\" xmlns=\"http://www.w3.org/2000/svg\">\n                    <circle cx=\"24\" cy=\"24\" r=\"18\" stroke-dasharray=\"113.097\" stroke-dashoffset=\"56.549\" stroke-width=\"4\"/>\n                </svg>\n            </div>\n            <div class=\"mdc-circular-progress__gap-patch\">\n                <svg class=\"mdc-circular-progress__indeterminate-circle-graphic\" viewBox=\"0 0 48 48\" xmlns=\"http://www.w3.org/2000/svg\">\n                    <circle cx=\"24\" cy=\"24\" r=\"18\" stroke-dasharray=\"113.097\" stroke-dashoffset=\"56.549\" stroke-width=\"3.2\"/>\n                </svg>\n            </div>\n            <div class=\"mdc-circular-progress__circle-clipper mdc-circular-progress__circle-right\">\n                <svg class=\"mdc-circular-progress__indeterminate-circle-graphic\" viewBox=\"0 0 48 48\" xmlns=\"http://www.w3.org/2000/svg\">\n                    <circle cx=\"24\" cy=\"24\" r=\"18\" stroke-dasharray=\"113.097\" stroke-dashoffset=\"56.549\" stroke-width=\"4\"/>\n                </svg>\n            </div>\n        </div>\n    </div>\n</div>\n";

let MooCircularProgress = class MooCircularProgress {
    progressEl;
    size;
    attached() {
        const progress = new circularProgress.MDCCircularProgress(this.progressEl);
        progress.determinate = false;
        progress.open();
    }
};
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Number)
], MooCircularProgress.prototype, "size", void 0);
MooCircularProgress = tslib.__decorate([
    runtimeHtml.customElement({
        name: 'moo-circular-progress',
        template: template$e,
        containerless: true
    })
], MooCircularProgress);

const mooFab = '';

const template$d = "<button if.bind=\"!url && !route\" class=\"mdc-fab ${extendedClass} ${class}\" aria-label=\"${icon}\" ref=\"fabEl\" click.trigger=\"handleClick()\">\n    <div class=\"mdc-fab__ripple\"></div>\n    <span class=\"mdc-fab__icon material-icons\">${icon}</span>\n    <span class=\"mdc-fab__label\">${label}</span>\n</button>\n<a if.bind=\"url\" href=\"${url}\" class=\"mdc-fab ${extendedClass} ${class}\" aria-label=\"${icon}\" ref=\"fabEl\" external target=\"_blank\">\n    <div class=\"mdc-fab__ripple\"></div>\n    <span class=\"mdc-fab__icon material-icons\">${icon}</span>\n    <span class=\"mdc-fab__label\">${label}</span>\n</a>\n<a if.bind=\"route\" load=\"${route}\" class=\"mdc-fab ${extendedClass} ${class}\" aria-label=\"${icon}\" ref=\"fabEl\">\n    <div class=\"mdc-fab__ripple\"></div>\n    <span class=\"mdc-fab__icon material-icons\">${icon}</span>\n    <span class=\"mdc-fab__label\">${label}</span>\n</a>\n";

let MooFab = class MooFab {
    icon;
    label;
    class;
    click;
    external;
    url;
    route;
    fabEl;
    attached() {
        new ripple.MDCRipple(this.fabEl);
    }
    handleClick() {
        if (this.click) {
            this.click();
        }
    }
    get extendedClass() {
        if (this.label) {
            return 'mdc-fab--extended';
        }
        return 'mdc-fab--mini';
    }
};
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", String)
], MooFab.prototype, "icon", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", String)
], MooFab.prototype, "label", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", String)
], MooFab.prototype, "class", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Object)
], MooFab.prototype, "click", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Boolean)
], MooFab.prototype, "external", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", String)
], MooFab.prototype, "url", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", String)
], MooFab.prototype, "route", void 0);
MooFab = tslib.__decorate([
    runtimeHtml.customElement({
        name: 'moo-fab',
        template: template$d,
        containerless: true
    })
], MooFab);

const template$c = "<label class=\"pt-1 pe-1\" for=\"switch\">${label}</label>\n<md-switch ref=\"switch\" selected.bind=\"value\" id=\"switch\"></md-switch>\n";

let MooSwitch = class MooSwitch {
    value;
    class;
    change;
    label;
    switch;
    attached() {
        this.switch.selected = this.value;
        this.switch.addEventListener('change', ()=>this.handleChange());
    }
    handleChange() {
        this.value = !this.value;
        this.change();
    }
};
tslib.__decorate([
    runtimeHtml.bindable({
        mode: 6 /* BindingMode.twoWay */ 
    }),
    tslib.__metadata("design:type", Boolean)
], MooSwitch.prototype, "value", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", String)
], MooSwitch.prototype, "class", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Function)
], MooSwitch.prototype, "change", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", String)
], MooSwitch.prototype, "label", void 0);
MooSwitch = tslib.__decorate([
    runtimeHtml.customElement({
        name: 'moo-switch',
        template: template$c,
        containerless: true
    })
], MooSwitch);

const mooTabBar = '';

const template$b = "<div class=\"mdc-tab-bar ${class}\" role=\"tablist\" ref=\"tabBarEl\">\n    <div class=\"mdc-tab-scroller\">\n        <div class=\"mdc-tab-scroller__scroll-area\">\n            <div class=\"mdc-tab-scroller__scroll-content\">\n                <au-slot></au-slot>\n            </div>\n        </div>\n    </div>\n</div>\n";

let MooTabBar = class MooTabBar {
    id;
    class;
    tabBarEl;
    attached() {
        new tabBar.MDCTabBar(this.tabBarEl);
    }
};
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", String)
], MooTabBar.prototype, "id", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", String)
], MooTabBar.prototype, "class", void 0);
MooTabBar = tslib.__decorate([
    runtimeHtml.customElement({
        name: 'moo-tab-bar',
        template: template$b,
        containerless: true,
        capture: true
    })
], MooTabBar);

const template$a = "<button class=\"mdc-tab ${tabClass}\" role=\"tab\" aria-selected=\"true\" tabindex=\"0\" click.trigger=\"setTab()\" type=\"button\">\n          <span class=\"mdc-tab__content\">\n            <span class=\"mdc-tab__icon material-icons\" aria-hidden=\"true\" if.bind=\"icon\">${icon}</span>\n            <span class=\"mdc-tab__text-label\">${label}</span>\n          </span>\n    <span class=\"mdc-tab-indicator ${indicatorClass}\">\n            <span class=\"mdc-tab-indicator__content mdc-tab-indicator__content--underline\"></span>\n          </span>\n    <span class=\"mdc-tab__ripple\"></span>\n    <div class=\"mdc-tab__focus-ring\"></div>\n</button>\n";

let MooTab = class MooTab {
    active;
    id;
    class;
    label;
    icon;
    tab;
    value;
    get tabClass() {
        if (this.active) {
            return 'mdc-tab--active';
        }
        return '';
    }
    get indicatorClass() {
        if (this.active) {
            return 'mdc-tab-indicator--active';
        }
        return '';
    }
    setTab() {
        this.tab = this.value;
    }
};
tslib.__decorate([
    runtimeHtml.bindable({
        mode: 6 /* BindingMode.twoWay */ 
    }),
    tslib.__metadata("design:type", Boolean)
], MooTab.prototype, "active", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Object)
], MooTab.prototype, "id", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Object)
], MooTab.prototype, "class", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Object)
], MooTab.prototype, "label", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Object)
], MooTab.prototype, "icon", void 0);
tslib.__decorate([
    runtimeHtml.bindable({
        mode: 6 /* BindingMode.twoWay */ 
    }),
    tslib.__metadata("design:type", Object)
], MooTab.prototype, "tab", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Object)
], MooTab.prototype, "value", void 0);
MooTab = tslib.__decorate([
    runtimeHtml.customElement({
        name: 'moo-tab',
        template: template$a,
        containerless: true
    })
], MooTab);

const template$9 = "<div if.bind=\"!options\">\n    <h4 class=\"text-danger\">SELECT NEEDS UPDATE</h4>\n</div>\n<md-outlined-select ...$attrs if.bind=\"selectType === 'outlined'\" class.bind=\"class\" required.bind=\"required\" onchange.bind=\"(e) => handleChange(e)\" label.bind=\"label\" value.bind=\"value\">\n    <md-select-option aria-label=\"blank\" if.bind=\"includeNull\"></md-select-option>\n    <md-select-option repeat.for=\"option of options\" value=\"${option.value}\" repeat.for=\"option of options\">\n        <div slot=\"headline\">${option.label}</div>\n    </md-select-option>\n</md-outlined-select>\n\n\n<md-filled-select ...$attrs else class.bind=\"class\" required.bind=\"required\" onchange.bind=\"(e) => handleChange(e)\" label.bind=\"label\" value.bind=\"value\">\n    <md-select-option aria-label=\"blank\" if.bind=\"includeNull\"></md-select-option>\n    <md-select-option repeat.for=\"option of options\" value=\"${option.value}\" repeat.for=\"option of options\">\n        <div slot=\"headline\">${option.label}</div>\n    </md-select-option>\n</md-filled-select>\n";

let MooSelect = class MooSelect {
    label;
    options;
    value;
    class;
    required;
    readonly;
    selectType = 'outlined';
    includeNull = false;
    handleChange(e) {
        this.value = e.target.value;
    }
};
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", String)
], MooSelect.prototype, "label", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Array)
], MooSelect.prototype, "options", void 0);
tslib.__decorate([
    runtimeHtml.bindable({
        mode: 6 /* BindingMode.twoWay */ 
    }),
    tslib.__metadata("design:type", Object)
], MooSelect.prototype, "value", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", String)
], MooSelect.prototype, "class", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Boolean)
], MooSelect.prototype, "required", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Boolean)
], MooSelect.prototype, "readonly", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", String)
], MooSelect.prototype, "selectType", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Object)
], MooSelect.prototype, "includeNull", void 0);
MooSelect = tslib.__decorate([
    runtimeHtml.customElement({
        name: 'moo-select',
        template: template$9,
        containerless: true
    })
], MooSelect);

const mooList = '';

const template$8 = "<ul class=\"mdc-deprecated-list\">\n    <au-slot></au-slot>\n</ul>\n";

let MooList = class MooList {
};
MooList = tslib.__decorate([
    runtimeHtml.customElement({
        name: 'moo-list',
        template: template$8,
        containerless: true
    })
], MooList);

const mooBanner = '';

const template$7 = "<div class=\"mdc-banner\" role=\"banner\" ref=\"bannerEl\">\n    <div class=\"mdc-banner__content\"\n         role=\"alertdialog\"\n         aria-live=\"assertive\">\n        <div class=\"mdc-banner__graphic-text-wrapper\">\n            <div class=\"mdc-banner__text\">\n                <au-slot></au-slot>\n            </div>\n        </div>\n        <div class=\"mdc-banner__actions\">\n            <moo-button variant=\"secondary\" type=\"button\" class=\"mdc-banner__secondary-action\" if.bind=\"secondaryAction\">\n                <div class=\"mdc-button__ripple\"></div>\n                <div class=\"mdc-button__label\">\n                    ${secondaryAction}\n                </div>\n            </moo-button>\n            <moo-button variant=\"primary\" type=\"button\" class=\"mdc-banner__primary-action\" if.bind=\"primaryAction\">\n                <div class=\"mdc-button__ripple\"></div>\n                <div class=\"mdc-button__label\">\n                    ${primaryAction}\n                </div>\n            </moo-button>\n        </div>\n    </div>\n</div>\n";

let MooBanner = class MooBanner {
    primaryAction;
    secondaryAction;
    open;
    bannerEl;
    banner;
    attached() {
        this.banner = new banner.MDCBanner(this.bannerEl);
        if (this.open) {
            this.banner.open();
        }
    }
    openChanged() {
        if (this.open) {
            this.banner.open();
        } else {
            this.banner.close(banner.CloseReason.PRIMARY);
        }
    }
};
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Object)
], MooBanner.prototype, "primaryAction", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Object)
], MooBanner.prototype, "secondaryAction", void 0);
tslib.__decorate([
    runtimeHtml.bindable({
        mode: 6 /* BindingMode.twoWay */ 
    }),
    tslib.__metadata("design:type", Object)
], MooBanner.prototype, "open", void 0);
MooBanner = tslib.__decorate([
    runtimeHtml.customElement({
        name: 'moo-banner',
        template: template$7,
        containerless: true,
        capture: true
    })
], MooBanner);

const mooAccordion = '';

const template$6 = "<div class=\"accordion-item ${extraAccordionClasses}\" ref=\"accordionItemEl\" ...$attrs>\n    <div class=\"accordion-header\" tabindex=\"0\" ref=\"accordionHeaderEl\">\n        <span>${header}</span>\n    </div>\n    <div class=\"accordion-content\">\n        <au-slot></au-slot>\n    </div>\n</div>\n";

let MooAccordion = class MooAccordion {
    header;
    accordionItemEl;
    accordionHeaderEl;
    closeAllOtherAccordions(element) {
        const accordionHeaders = document.querySelectorAll('.accordion-header');
        accordionHeaders.forEach((header)=>{
            if (header !== element) {
                // eslint-disable-next-line @typescript-eslint/ban-ts-comment
                // @ts-ignore
                header.parentElement.classList.remove('accordion-expanded');
                // eslint-disable-next-line @typescript-eslint/ban-ts-comment
                // @ts-expect-error
                header.nextElementSibling.style.maxHeight = 0;
            }
        });
    }
    attached() {
        this.accordionHeaderEl.addEventListener('click', ()=>{
            const content = this.accordionHeaderEl.nextElementSibling;
            // eslint-disable-next-line @typescript-eslint/ban-ts-comment
            // @ts-ignore
            const isOpen = this.accordionHeaderEl.parentElement.classList.contains('accordion-expanded');
            this.closeAllOtherAccordions(this.accordionHeaderEl);
            if (isOpen) {
                content.style.maxHeight = '0';
            } else {
                content.style.maxHeight = content.scrollHeight + 50 + 'px';
            }
            // eslint-disable-next-line @typescript-eslint/ban-ts-comment
            // @ts-ignore
            this.accordionHeaderEl.parentElement.classList.toggle('accordion-expanded');
        });
    }
};
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", String)
], MooAccordion.prototype, "header", void 0);
MooAccordion = tslib.__decorate([
    runtimeHtml.customElement({
        name: 'moo-accordion',
        template: template$6,
        containerless: true,
        capture: true
    })
], MooAccordion);

const mooRadio = '';

const template$5 = "<div class=\"mdc-radio\" ref=\"radioEl\">\n    <input class=\"mdc-radio__native-control\" type=\"radio\" name=\"radios\" checked.bind=\"checked\" disabled.bind=\"disabled\">\n    <div class=\"mdc-radio__background\">\n        <div class=\"mdc-radio__outer-circle\"></div>\n        <div class=\"mdc-radio__inner-circle\"></div>\n    </div>\n    <div class=\"mdc-radio__ripple\"></div>\n    <div class=\"mdc-radio__focus-ring\"></div>\n</div>\n";

let MooRadio = class MooRadio {
    label;
    options;
    model;
    value;
    class;
    disabled;
    checked = false;
    radioEl;
    radio;
    attached() {
        if (this.model == this.value) {
            this.checked = true;
        }
        console.log('this.model', this.model);
        console.log('this.value', this.value);
        this.radio = new radio.MDCRadio(this.radioEl);
        console.log(this.checked);
    }
    clickHandler() {
        console.log('clicked', this.radio.value);
    }
    handleRadioChecked() {
        console.log('radio checked', this.radio.checked);
    }
    handleRadioValue() {
        console.log('radio value', this.radio.value);
    }
    handleCheckChanged() {
        console.log('this.checked', this.checked);
    }
};
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", String)
], MooRadio.prototype, "label", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Object)
], MooRadio.prototype, "options", void 0);
tslib.__decorate([
    runtimeHtml.bindable({
        mode: 6 /* BindingMode.twoWay */ 
    }),
    tslib.__metadata("design:type", Object)
], MooRadio.prototype, "model", void 0);
tslib.__decorate([
    runtimeHtml.bindable({
        mode: 6 /* BindingMode.twoWay */ 
    }),
    tslib.__metadata("design:type", Object)
], MooRadio.prototype, "value", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", String)
], MooRadio.prototype, "class", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Boolean)
], MooRadio.prototype, "disabled", void 0);
tslib.__decorate([
    runtimeHtml.watch('radio.checked'),
    tslib.__metadata("design:type", Function),
    tslib.__metadata("design:paramtypes", []),
    tslib.__metadata("design:returntype", void 0)
], MooRadio.prototype, "handleRadioChecked", null);
tslib.__decorate([
    runtimeHtml.watch('radio'),
    tslib.__metadata("design:type", Function),
    tslib.__metadata("design:paramtypes", []),
    tslib.__metadata("design:returntype", void 0)
], MooRadio.prototype, "handleRadioValue", null);
tslib.__decorate([
    runtimeHtml.watch('checked'),
    tslib.__metadata("design:type", Function),
    tslib.__metadata("design:paramtypes", []),
    tslib.__metadata("design:returntype", void 0)
], MooRadio.prototype, "handleCheckChanged", null);
MooRadio = tslib.__decorate([
    runtimeHtml.customElement({
        name: 'moo-radio',
        template: template$5,
        containerless: true
    })
], MooRadio);

const mooFormField = '';

const template$4 = "<div class=\"mdc-form-field\" ref=\"formFieldEl\">\n    <au-slot></au-slot>\n    <label>${label}</label>\n</div>\n";

let MooFormField = class MooFormField {
    label;
    options;
    class;
    disabled;
    formFieldEl;
    formField;
    attached() {
        this.formField = new formField.MDCFormField(this.formFieldEl);
    }
};
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Object)
], MooFormField.prototype, "label", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Object)
], MooFormField.prototype, "options", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Object)
], MooFormField.prototype, "class", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Boolean)
], MooFormField.prototype, "disabled", void 0);
MooFormField = tslib.__decorate([
    runtimeHtml.customElement({
        name: 'moo-form-field',
        template: template$4,
        containerless: true
    })
], MooFormField);

const mooChipSet = '';

const template$3 = "<span class=\"mdc-evolution-chip-set\" role=\"grid\" ref=\"chipSetEl\">\n    <span class=\"mdc-evolution-chip-set__chips\" role=\"presentation\">\n        <au-slot></au-slot>\n    </span>\n</span>\n";

let MooChipSet = class MooChipSet {
    chipSetEl;
    size;
    attached() {
        new chips.MDCChipSet(this.chipSetEl);
    }
};
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Number)
], MooChipSet.prototype, "size", void 0);
MooChipSet = tslib.__decorate([
    runtimeHtml.customElement({
        name: 'moo-chip-set',
        template: template$3,
        containerless: true
    })
], MooChipSet);

const mooChip = '';

const template$2 = "<span class=\"mdc-evolution-chip\" role=\"row\" id=\"c0\">\n      <span class=\"mdc-evolution-chip__cell mdc-evolution-chip__cell--primary\" role=\"gridcell\">\n        <button class=\"mdc-evolution-chip__action mdc-evolution-chip__action--primary\" type=\"button\" tabindex=\"0\">\n          <span class=\"mdc-evolution-chip__ripple mdc-evolution-chip__ripple--primary\"></span>\n          <span class=\"mdc-evolution-chip__text-label\">\n              <au-slot></au-slot>\n          </span>\n        </button>\n      </span>\n    </span>\n";

let MooChip = class MooChip {
};
MooChip = tslib.__decorate([
    runtimeHtml.customElement({
        name: 'moo-chip',
        template: template$2,
        containerless: true
    })
], MooChip);

const mooCheckbox = '';

const template$1 = "<div class=\"mdc-touch-target-wrapper\">\n    <div class=\"mdc-checkbox mdc-checkbox--touch\" ref=\"checkboxEl\">\n        <input type=\"checkbox\"\n               class=\"mdc-checkbox__native-control\"\n               checked.bind=\"checked\"/>\n        <div class=\"mdc-checkbox__background\">\n            <svg class=\"mdc-checkbox__checkmark\"\n                 viewBox=\"0 0 24 24\">\n                <path class=\"mdc-checkbox__checkmark-path\"\n                      fill=\"none\"\n                      d=\"M1.73,12.91 8.1,19.28 22.79,4.59\"/>\n            </svg>\n            <div class=\"mdc-checkbox__mixedmark\"></div>\n        </div>\n        <div class=\"mdc-checkbox__ripple\"></div>\n        <div class=\"mdc-checkbox__focus-ring\"></div>\n    </div>\n</div>\n";

let MooCheckbox = class MooCheckbox {
    checkboxEl;
    checked;
    changed;
    value;
    attached() {
        new checkbox.MDCCheckbox(this.checkboxEl);
    }
    checkedChanged() {
        if (this.changed) {
            this.changed(this.value, this.checked);
        }
    }
};
tslib.__decorate([
    runtimeHtml.bindable({
        mode: 6 /* BindingMode.twoWay */ 
    }),
    tslib.__metadata("design:type", Boolean)
], MooCheckbox.prototype, "checked", void 0);
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Object)
], MooCheckbox.prototype, "changed", void 0);
tslib.__decorate([
    runtimeHtml.bindable({
        mode: 6 /* BindingMode.twoWay */ 
    }),
    tslib.__metadata("design:type", String)
], MooCheckbox.prototype, "value", void 0);
MooCheckbox = tslib.__decorate([
    runtimeHtml.customElement({
        name: 'moo-checkbox',
        template: template$1,
        containerless: true
    })
], MooCheckbox);

const mooMenu = '';

const template = "<div class=\"mdc-menu mdc-menu-surface\" ref=\"menuEl\">\n    <au-slot></au-slot>\n</div>\n";

let MooMenu = class MooMenu {
    open = false;
    menuEl;
    menu;
    attached() {
        this.menu = new menu.MDCMenu(this.menuEl);
        this.menu.open = this.open;
    }
    openChanged() {
        if (this.menu) {
            this.menu.open = this.open;
        }
    }
};
tslib.__decorate([
    runtimeHtml.bindable,
    tslib.__metadata("design:type", Object)
], MooMenu.prototype, "open", void 0);
MooMenu = tslib.__decorate([
    runtimeHtml.customElement({
        name: 'moo-menu',
        template,
        containerless: true
    })
], MooMenu);

const elements = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
    __proto__: null,
    get MooAccordion () { return MooAccordion; },
    get MooBanner () { return MooBanner; },
    get MooButton () { return MooButton; },
    get MooCard () { return MooCard; },
    get MooCardContent () { return MooCardContent; },
    get MooCardFooter () { return MooCardFooter; },
    get MooCardHeader () { return MooCardHeader; },
    get MooCheckbox () { return MooCheckbox; },
    get MooChip () { return MooChip; },
    get MooChipSet () { return MooChipSet; },
    get MooCircularProgress () { return MooCircularProgress; },
    get MooDialog () { return MooDialog; },
    get MooDrawer () { return MooDrawer; },
    get MooFab () { return MooFab; },
    get MooFormField () { return MooFormField; },
    get MooList () { return MooList; },
    get MooListItem () { return MooListItem; },
    get MooMenu () { return MooMenu; },
    get MooRadio () { return MooRadio; },
    get MooSelect () { return MooSelect; },
    get MooSwitch () { return MooSwitch; },
    get MooTab () { return MooTab; },
    get MooTabBar () { return MooTabBar; },
    get MooTextField () { return MooTextField; },
    get MooTopbar () { return MooTopbar; }
}, Symbol.toStringTag, { value: 'Module' }));

let TakeValueConverter = class TakeValueConverter {
    toView(value, amount) {
        return value.slice(0, amount);
    }
};
TakeValueConverter = tslib.__decorate([
    runtimeHtml.valueConverter('take')
], TakeValueConverter);

let SkipValueConverter = class SkipValueConverter {
    toView(value, amount) {
        return value.slice(amount);
    }
};
SkipValueConverter = tslib.__decorate([
    runtimeHtml.valueConverter('skip')
], SkipValueConverter);

const valueConverters = /*#__PURE__*/Object.freeze(/*#__PURE__*/Object.defineProperty({
    __proto__: null,
    get SkipValueConverter () { return SkipValueConverter; },
    get TakeValueConverter () { return TakeValueConverter; }
}, Symbol.toStringTag, { value: 'Module' }));

const main = '';

class BetsyWebComponentsPlugin {
    #configuration;
    static configure(...args) {
        const instance = new BetsyWebComponentsPlugin();
        if (typeof args[0] === 'function') {
            instance.#configuration = {
                iconMap: new Map()
            };
            args[0](instance.#configuration);
        } else {
            instance.#configuration = args[0];
        }
        if (!instance.#configuration.formatDateTime) {
            instance.#configuration.formatDateTime = (date)=>new Intl.DateTimeFormat('default', {
                    dateStyle: 'full'
                }).format(typeof date === 'string' ? new Date(date) : date);
        }
        if (!instance.#configuration.formatDate) {
            instance.#configuration.formatDate = (date)=>new Intl.DateTimeFormat('default', {
                    month: '2-digit',
                    day: '2-digit',
                    year: 'numeric'
                }).format(typeof date === 'string' ? new Date(date) : date);
        }
        if (!instance.#configuration.formatNumber) {
            instance.#configuration.formatNumber = (number)=>new Intl.NumberFormat('default', {
                    maximumFractionDigits: 2
                }).format(number == null ? 0 : Number(number));
        }
        if (!instance.#configuration.formatCurrency) {
            instance.#configuration.formatCurrency = (number)=>new Intl.NumberFormat('default', {
                    style: 'currency',
                    currency: 'usd'
                }).format(number == null ? 0 : Number(number));
        }
        if (!instance.#configuration.formatPercent) {
            instance.#configuration.formatPercent = (number)=>new Intl.NumberFormat('default', {
                    style: 'percent'
                }).format(number == null ? 0 : Number(number));
        }
        return instance;
    }
    register(container) {
        container.register(attributes);
        container.register(elements);
        container.register(valueConverters);
        container.register(kernel.Registration.instance(IBetsyWebComponentsConfiguration, this.#configuration));
        container.register(validationHtml.ValidationHtmlConfiguration.customize((options)=>{
            options.DefaultTrigger = validationHtml.ValidationTrigger.changeOrFocusout;
        }));
        // container = container.register(AppTask.beforeCreate(IContainer, async c => {
        //     // console
        //     console.log(this.#configuration)
        //     c.register(elements);
        //     c.register(attributes);
        // }));
        return container;
    }
}

exports.BetsyWebComponentsPlugin = BetsyWebComponentsPlugin;
exports.IBetsyWebComponentsConfiguration = IBetsyWebComponentsConfiguration;
exports.attributes = attributes;
exports.elements = elements;
exports.valueConverters = valueConverters;
//# sourceMappingURL=index.js.map
